@@ -37,6 +37,7 @@ import asyncio
 
 # ==================================================================================== #
 class ClientSingleton(Decorator):
+    _err_not_open = 'Session has not been opened! (YFrake)'
     __instance__ = None
 
     # Singleton pattern
@@ -48,8 +49,10 @@ class ClientSingleton(Decorator):
 
     # ------------------------------------------------------------------------------------ #
     @classmethod
-    async def _wrapper(cls, endpoint, kwargs, func, resp) -> ClientResponse:
-        result = await func(endpoint, kwargs)
+    async def _wrapper(cls, endpoint, params, resp) -> ClientResponse:
+        attr = 'get_' + endpoint
+        func = getattr(endpoints, attr)
+        result = await func(endpoint, params)
         setattr(resp, '_endpoint', result['endpoint'])
         setattr(resp, '_error', result['error'])
         setattr(resp, '_data', result['data'])
@@ -65,21 +68,19 @@ class ClientSingleton(Decorator):
         Returns immediately with the pending
         ClientResponse object.
         """
-        if not cls._initialized:
-            raise RuntimeError(cls._err_cfg_missing)
+        if not cls._config.is_locked():
+            raise RuntimeError(cls._err_not_open)
         validate_request(endpoint, kwargs)
 
-        attr = 'get_' + endpoint
-        func = getattr(endpoints, attr)
         resp = ClientResponse(cls._async_mode)
-
         if cls._async_mode:
             future = asyncio.create_task(
-                cls._wrapper(endpoint, kwargs, func, resp))
+                cls._wrapper(endpoint, kwargs, resp))
         else:
             ss = SessionSingleton()
             future = asyncio.run_coroutine_threadsafe(
-                cls._wrapper(endpoint, kwargs, func, resp), ss.loop)
+                cls._wrapper(endpoint, kwargs, resp), ss.loop)
+
         setattr(resp, '_future', future)
         return resp
 
