@@ -27,39 +27,49 @@
 # ==================================================================================== #
 from aiohttp_swagger3 import SwaggerFile
 from aiohttp_swagger3 import SwaggerUiSettings
-import aiohttp_cors as cors
+from aiohttp import web
+import aiohttp_cors
 
 
-# These functions are called sequentially by the runner.py module.
-
 # ==================================================================================== #
-def create_swagger(app, spec) -> SwaggerFile:
+def create_swagger(app, spec):
     app['storage'] = dict()
-    return SwaggerFile(
+    swagger = SwaggerFile(
         app=app,
         spec_file=str(spec),
         swagger_ui_settings=SwaggerUiSettings(path="/"),
         validate=False
     )
+    return swagger
 
 
 # ------------------------------------------------------------------------------------ #
 def create_cors(app):
-    cors_options = cors.ResourceOptions(
+    options = aiohttp_cors.ResourceOptions(
         allow_credentials=True,
         expose_headers="*",
         allow_headers="*"
     )
-    return cors.setup(
+    cors = aiohttp_cors.setup(
         app=app,
-        defaults={'*': cors_options}
+        defaults={'*': options}
     )
+    return cors
 
 
 # ------------------------------------------------------------------------------------ #
-def print_notification(host, port):
-    message = f'Running the YFrake server at: http://{host}:{port}'
-    print('=' * len(message))
-    print(message)
-    print('=' * len(message))
-    print('\n')
+def create_site(runner, config):
+    site = web.TCPSite(
+        runner=runner,
+        host=config.host,
+        port=config.port,
+        backlog=config.backlog
+    )
+    return site
+
+
+# ------------------------------------------------------------------------------------ #
+def notify_user(host, port):
+    msg = f'Running YFrake server at: http://{host}:{port}'
+    sep = '-' * len(msg)
+    print(sep + '\n' + msg + '\n' + sep)
